<?
        /* This Source Code Form is subject to the terms of the Mozilla Public
         * License, v. 2.0. If a copy of the MPL was not distributed with this
         * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

        // Add the X-Frame-Options header to prevent clickjacking
        header("X-Frame-Options: DENY");

        require_once('../includes/functions.php');
        require_once('../includes/authenticate.php');
	require_once('../includes/config.php');

        // Database version to upgrade
        $version_to_upgrade = "20130827-001";

        // Database version upgrading to
        $version_upgrading_to = "20130915-001";

        // Start the session
        session_start('SimpleRiskDBUpgrade');

        // Check for session timeout or renegotiation
        session_check();

        // If the user requested a logout
        if ($_GET['logout'] == "true")
        {
        	// Deny access
        	$_SESSION["access"] = "denied";

        	// Reset the session data
        	$_SESSION = array();

        	// Send a Set-Cookie to invalidate the session cookie
        	if (isset($_COOKIES[session_name90]))
        	{
                	$params = session_get_cookie_params();
                	setcookie(session_name(), '', 1, $params['path'], $params['domain'], $params['secure'], isset($params['httponly']));
        	}

        	// Destroy the session
        	session_destroy();

        	// Redirect to the upgrade login form
        	header( 'Location: upgrade.php' );
	}

	// Default is no alert
	$alert = false;

        // If the login form was posted
        if (isset($_POST['submit']))
        {
                $user = $_POST['user'];
                $pass = $_POST['pass'];

                // If the user is valid
                if (is_valid_user($user, $pass))
                {
                        // Check if the user is an admin
                        if ($_SESSION["admin"] == "1")
                        {
                                // Grant access
                                $_SESSION["access"] = "granted";
                        }
                        // The user is not an admin
                        else
                        {
				$alert = true;
                                $alert_message = "You need to log in as an administrative user in order to upgrade the database.";

                                // Deny access
                                $_SESSION["access"] = "denied";
                        }
                }
                // The user was not valid
                else
                {
			// Send an alert
			$alert = true;

                        // Invalid username or password
                        $alert_message = "Invalid username or password.";

                        // Deny access
                        $_SESSION["access"] = "denied";
                }
        }
?>

<!doctype html>
<html>

  <head>
    <script src="../js/jquery.min.js"></script>
    <script src="../js/bootstrap.min.js"></script>
    <title>SimpleRisk: Enterprise Risk Management Simplified</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <link rel="stylesheet" href="../css/bootstrap.css">
    <link rel="stylesheet" href="../css/bootstrap-responsive.css"> 
  </head>

  <body>
    <? if ($alert) echo "<script>alert(\"" . $alert_message . "\");</script>" ?>
    <title>SimpleRisk: Enterprise Risk Management Simplified</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <link rel="stylesheet" href="../css/bootstrap.css">
    <link rel="stylesheet" href="../css/bootstrap-responsive.css">
    <link rel="stylesheet" href="../css/divshot-util.css">
    <link rel="stylesheet" href="../css/divshot-canvas.css">
    <div class="navbar">
      <div class="navbar-inner">
        <div class="container">
          <a class="brand" href="http://www.simplerisk.org/">SimpleRisk</a>
          <div class="navbar-content">
            <ul class="nav">
              <li>
                <a href="upgrade.php">Database Upgrade Script</a>
              </li>
              <li>
                <a href="upgrade.php?logout=true">Logout</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
    </div>
    <div class="container-fluid">
      <div class="row-fluid">
        <div class="span12">
          <div class="row-fluid">
            <div class="span12">
              <div class="hero-unit">
<?
	// If access was not granted display the login form
	if ($_SESSION["access"] != "granted")
	{
      		echo "<p><label><u>Log In Here</u></label></p>\n";
      		echo "<form name=\"authenticate\" method=\"post\" action=\"\">\n";
      		echo "Username: <input class=\"input-medium\" name=\"user\" id=\"user\" type=\"text\" /><br />\n";
      		echo "Password: <input class=\"input-medium\" name=\"pass\" id=\"pass\" type=\"password\" />\n";
		echo "<br />\n";
      		echo "<button type=\"submit\" name=\"submit\" class=\"btn btn-primary\">Login</button>\n";
      		echo "</form>\n";
	}
	// Otherwise access was granted so check if the user is an admin
	else if ($_SESSION["admin"] == "1")
        {
		// If CONTINUE was not pressed
		if (!isset($_POST['upgrade_database']))
		{
			// Get the current application version
			$app_version = current_version("app");

			echo "The current application version is: " . $app_version . "<br />\n";

			// Get the current database version
			$db_version = current_version("db");

			echo "The current database version is: " . $db_version . "<br />\n";

			// If the version to upgrade is the current version
			if ($db_version == $version_to_upgrade)
			{
				echo "This script will ugprade your database from version " . $version_to_upgrade . " to the version that goes with these application files.  Click &quot;CONTINUE&quot; to proceed.<br />\n";
				echo "<br />\n";
				echo "<form name=\"upgrade_database\" method=\"post\" action=\"\">\n";
				echo "<button type=\"submit\" name=\"upgrade_database\" class=\"btn btn-primary\">CONTINUE</button>\n";
				echo "</form>\n";
			}
			// Otherwise if the db version matches the app version
			else if ($db_version == $app_version)
			{
				echo "Your database is already upgraded to the version that matches your application files.  No additional upgrade is necessary to make it work properly.<br />\n";
			}
			// Otherwise this is not the right database version to upgrade
			else
			{
				echo "This script was meant to upgrade database version " . $version_to_upgrade . " but your current database version is " . $db_version . ".  You will need to use a different database upgrade script instead.<br />\n";
			}
		}
		// Otherwise, CONTINUE was pressed
		else
		{
			// Connect to the database
			echo "Connecting to the SimpleRisk database.<br />\n";
			$db = db_open();

			echo "Beginning upgrade of SimpleRisk database.<br />\n";

			/****************************
                 	* DATABASE CHANGES GO HERE *
		 	****************************/

			// Create new combined CVSS scoring table
			echo "Creating new combined CVSS scoring table.<br />\n";
			$stmt = $db->prepare("CREATE TABLE IF NOT EXISTS `CVSS_scoring` (
  				`id` int(11) NOT NULL AUTO_INCREMENT,
  				`metric_name` varchar(30) NOT NULL,
  				`abrv_metric_name` varchar(3) NOT NULL,
  				`metric_value` varchar(30) NOT NULL,
  				`abrv_metric_value` varchar(3) NOT NULL,
  				`numeric_value` float NOT NULL,
  				PRIMARY KEY (`id`)
				) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=56 ;
			");
			$stmt->execute();

			// Populating new combined CVSS scoring table
			echo "Populating the new combined CVSS scoring table.<br />\n";
			$stmt = $db->prepare("INSERT INTO `CVSS_scoring` (`id`, `metric_name`, `abrv_metric_name`, `metric_value`, `abrv_metric_value`, `numeric_value`) VALUES
				(1, 'AccessComplexity', 'AC', 'High', 'H', 0.35),
				(2, 'AccessComplexity', 'AC', 'Medium', 'M', 0.61),
				(3, 'AccessComplexity', 'AC', 'Low', 'L', 0.71),
				(4, 'AccessVector', 'AV', 'Local', 'L', 0.395),
				(5, 'AccessVector', 'AV', 'Adjacent Network', 'A', 0.646),
				(6, 'AccessVector', 'AV', 'Network', 'N', 1),
				(7, 'Authentication', 'Au', 'None', 'N', 0.704),
				(8, 'Authentication', 'Au', 'Single Instance', 'S', 0.56),
				(9, 'Authentication', 'Au', 'Multiple Instances', 'M', 0.45),
				(10, 'AvailabilityRequirement', 'AR', 'Undefined', 'ND', 1),
				(11, 'AvailabilityRequirement', 'AR', 'Low', 'L', 0.5),
				(12, 'AvailabilityRequirement', 'AR', 'Medium', 'M', 1),
				(13, 'AvailabilityRequirement', 'AR', 'High', 'H', 1.51),
				(14, 'AvailImpact', 'A', 'None', 'N', 0),
				(15, 'AvailImpact', 'A', 'Partial', 'P', 0.275),
				(16, 'AvailImpact', 'A', 'Complete', 'C', 0.66),
				(17, 'CollateralDamagePotential', 'CDP', 'Undefined', 'ND', 0),
				(18, 'CollateralDamagePotential', 'CDP', 'None', 'N', 0),
				(19, 'CollateralDamagePotential', 'CDP', 'Low (light loss)', 'L', 0.1),
				(20, 'CollateralDamagePotential', 'CDP', 'Low-Medium', 'LM', 0.3),
				(21, 'CollateralDamagePotential', 'CDP', 'Medium-High', 'MH', 0.4),
				(22, 'CollateralDamagePotential', 'CDP', 'High', 'H', 0.5),
				(23, 'ConfidentialityRequirement', 'CR', 'Undefined', 'ND', 1),
				(24, 'ConfidentialityRequirement', 'CR', 'Low', 'L', 0.5),
				(25, 'ConfidentialityRequirement', 'CR', 'Medium', 'M', 1),
				(26, 'ConfidentialityRequirement', 'CR', 'High', 'H', 1.51),
				(27, 'ConfImpact', 'C', 'None', 'N', 0),
				(28, 'ConfImpact', 'C', 'Partial', 'P', 0.275),
				(29, 'ConfImpact', 'C', 'Complete', 'C', 0.66),
				(30, 'Exploitability', 'E', 'Undefined', 'ND', 1),
				(31, 'Exploitability', 'E', 'Unproven that exploit exists', 'U', 0.85),
				(32, 'Exploitability', 'E', 'Proof of concept code', 'POC', 0.9),
				(33, 'Exploitability', 'E', 'Functional exploit exists', 'F', 0.95),
				(34, 'Exploitability', 'E', 'Widespread', 'H', 1),
				(35, 'IntegImpact', 'I', 'None', 'N', 0),
				(36, 'IntegImpact', 'I', 'Partial', 'P', 0.275),
				(37, 'IntegImpact', 'I', 'Complete', 'C', 0.66),
				(38, 'IntegrityRequirement', 'IR', 'Undefined', 'ND', 1),
				(39, 'IntegrityRequirement', 'IR', 'Low', 'L', 0.5),
				(40, 'IntegrityRequirement', 'IR', 'Medium', 'M', 1),
				(41, 'IntegrityRequirement', 'IR', 'High', 'H', 1.51),
				(42, 'RemediationLevel', 'RL', 'Undefined', 'ND', 1),
				(43, 'RemediationLevel', 'RL', 'Official fix', 'OF', 0.87),
				(44, 'RemediationLevel', 'RL', 'Temporary fix', 'TF', 0.9),
				(45, 'RemediationLevel', 'RL', 'Workaround', 'W', 0.95),
				(46, 'RemediationLevel', 'RL', 'Unavailable', 'U', 1),
				(47, 'ReportConfidence', 'RC', 'Undefined', 'ND', 1),
				(48, 'ReportConfidence', 'RC', 'Unconfirmed', 'UC', 0.9),
				(49, 'ReportConfidence', 'RC', 'Uncorroborated', 'UR', 0.95),
				(50, 'ReportConfidence', 'RC', 'Confirmed', 'C', 1),
				(51, 'TargetDistribution', 'TD', 'Undefined', 'ND', 1),
				(52, 'TargetDistribution', 'TD', 'None (0%)', 'N', 0),
				(53, 'TargetDistribution', 'TD', 'Low (0-25%)', 'L', 0.25),
				(54, 'TargetDistribution', 'TD', 'Medium (26-75%)', 'M', 0.75),
				(55, 'TargetDistribution', 'TD', 'High (76-100%)', 'H', 1);
			");
			$stmt->execute();

                        // Drop obsolete individual CVSS scoring tables
                        echo "Dropping obsolete individual CVSS scoring tables.<br />\n";
                        $stmt = $db->prepare("DROP TABLE `CVSS_AccessComplexity`, `CVSS_AccessVector`, `CVSS_Authentication`, `CVSS_AvailabilityRequirement`, `CVSS_AvailImpact`, `CVSS_CollateralDamagePotential`, `CVSS_ConfidentialityRequirement`, `CVSS_ConfImpact`, `CVSS_Exploitability`, `CVSS_IntegImpact`, `CVSS_IntegrityRequirement`, `CVSS_RemediationLevel`, `CVSS_ReportConfidence`, `CVSS_TargetDistribution`");
			$stmt->execute();

			// Create a temporary table for risk scoring data
			echo "Creating a temporary table for risk scoring data.<br />\n";
			$stmt = $db->prepare("CREATE TABLE risk_scoring_tmp LIKE risk_scoring");
			$stmt->execute();

			// Populate the temporary table with risk scoring data
			echo "Populating the temporary table with risk scoring data.<br />\n";
			$stmt = $db->prepare("INSERT risk_scoring_tmp SELECT * FROM risk_scoring");
			$stmt->execute();

			// Change CVSS columns from float to varchar in risk scoring table
			echo "Changing data type for CVSS columns in risk scoring table.<br />\n";
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_AccessVector` `CVSS_AccessVector` VARCHAR( 3 ) NOT NULL");
			$stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_AccessComplexity` `CVSS_AccessComplexity` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_Authentication` `CVSS_Authentication` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_ConfImpact` `CVSS_ConfImpact` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_IntegImpact` `CVSS_IntegImpact` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_AvailImpact` `CVSS_AvailImpact` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_Exploitability` `CVSS_Exploitability` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_RemediationLevel` `CVSS_RemediationLevel` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_ReportConfidence` `CVSS_ReportConfidence` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_CollateralDamagePotential` `CVSS_CollateralDamagePotential` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_TargetDistribution` `CVSS_TargetDistribution` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_ConfidentialityRequirement` `CVSS_ConfidentialityRequirement` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_IntegrityRequirement` `CVSS_IntegrityRequirement` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` CHANGE `CVSS_AvailabilityRequirement` `CVSS_AvailabilityRequirement` VARCHAR( 3 ) NOT NULL");
                        $stmt->execute();

			// Update the CVSS_AccessVector column
			echo "Updating the CVSS AccessVector column.<br />\n";
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_AccessVector = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_AccessVector = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'AV'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_AccessComplexity = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_AccessComplexity = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'AC'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_Authentication = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_Authentication = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'Au'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_ConfImpact = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_ConfImpact = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'C'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_IntegImpact = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_IntegImpact = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'I'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_AvailImpact = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_AvailImpact = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'A'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_Exploitability = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_Exploitability = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'E'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_RemediationLevel = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_RemediationLevel = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'RL'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_ReportConfidence = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_ReportConfidence = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'RC'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_CollateralDamagePotential = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_CollateralDamagePotential = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'CDP'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_TargetDistribution = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_TargetDistribution = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'TD'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_ConfidentialityRequirement = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_ConfidentialityRequirement = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'CR'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_IntegrityRequirement = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_IntegrityRequirement = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'IR'");
                        $stmt->execute();
			$stmt = $db->prepare("UPDATE risk_scoring_tmp AS t1 JOIN CVSS_scoring AS t2 ON t1.CVSS_AvailabilityRequirement = t2.numeric_value JOIN risk_scoring AS t3 ON t1.id = t3.id SET t3.CVSS_AvailabilityRequirement = t2.abrv_metric_value WHERE t2.abrv_metric_name = 'AR'");
                        $stmt->execute();

			// Update all columns with a 0 or -1 value
                        $stmt = $db->prepare("SHOW COLUMNS FROM risk_scoring");
                        $stmt->execute();
                        $result = $stmt->fetchAll();

                        foreach ($result as $row)
                        {
                                $stmt = $db->prepare("UPDATE risk_scoring SET " . $row['Field'] . " = '' WHERE " . $row['Field'] . " = '0'");
                                $stmt->execute();
                                $stmt = $db->prepare("UPDATE risk_scoring SET " . $row['Field'] . " = 'ND' WHERE " . $row['Field'] . " = '-1'");
                                $stmt->execute();
                        }

			// Make the id a unique key
			echo "Making the id column in the risk_scoring table unique.<br />\n";
			$stmt = $db->prepare("ALTER TABLE `risk_scoring` ADD UNIQUE (`id`)");
			$stmt->execute();

			// Delete the temporary risk scoring table
			echo "Deleting the temporary risk scoring table.<br />\n";
			$stmt = $db->prepare("DROP TABLE risk_scoring_tmp");
			$stmt->execute();

			/************************
		 	 * END DATABASE CHANGES *
		 	 ************************/

			// Update the database version information
			echo "Updating the database version information.<br />\n";
			$stmt = $db->prepare("UPDATE `settings` SET `value` = '" . $version_upgrading_to . "' WHERE `settings`.`name` = 'db_version' AND `settings`.`value` = '" . $version_to_upgrade . "' LIMIT 1 ;");
			$stmt->execute();

			// Disconnect from the database
			echo "Disconnecting from the SimpleRisk database.<br />\n";
        		db_close($db);

			echo "SimpleRisk database upgrade is complete.<br />\n";
		}
	}
?>

              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </body>

</html>
