<?
        /* This Source Code Form is subject to the terms of the Mozilla Public
         * License, v. 2.0. If a copy of the MPL was not distributed with this
         * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

        // Add the X-Frame-Options header to prevent clickjacking
        header("X-Frame-Options: DENY");

        // Include required functions file
        require_once('../includes/functions.php');
        require_once('../includes/authenticate.php');

        // Session handler is database
        if (USE_DATABASE_FOR_SESSIONS == "true")
        {
		session_set_save_handler('sess_open', 'sess_close', 'sess_read', 'sess_write', 'sess_destroy', 'sess_gc');
        }

        // Start the session
        session_start('SimpleRisk');

        // Check for session timeout or renegotiation
        session_check();

	// Default is no alert
	$alert = false;

	// Default is not approved
	$approved = false;

        // Check if access is authorized
        if ($_SESSION["access"] != "granted")
        {
                header("Location: ../index.php");
                exit(0);
        }

        // Check if a risk ID was sent
        if (isset($_GET['id']) || isset($_POST['id']))
        {
                if (isset($_GET['id']))
                {
                        $id = htmlentities($_GET['id']);
                }
                else if (isset($_POST['id']))
                {
                        $id = htmlentities($_POST['id']);
                }

                // Get the details of the risk
                $risk = get_risk_by_id($id);

                $status = htmlentities($risk[0]['status']);
                $subject = htmlentities(stripslashes($risk[0]['subject']));
                $reference_id = htmlentities(stripslashes($risk[0]['reference_id']));
                $location = htmlentities($risk[0]['location']);
                $category = htmlentities($risk[0]['category']);
                $team = htmlentities($risk[0]['team']);
                $technology = htmlentities($risk[0]['technology']);
                $owner = htmlentities($risk[0]['owner']);
                $manager = htmlentities($risk[0]['manager']);
                $assessment = htmlentities($risk[0]['assessment']);
                $notes = htmlentities($risk[0]['notes']);
                $submission_date = htmlentities($risk[0]['submission_date']);
                $mitigation_id = htmlentities($risk[0]['mitigation_id']);
                $mgmt_review = htmlentities($risk[0]['mgmt_review']);
                $calculated_risk = $risk[0]['calculated_risk'];
		$risk_level = get_risk_level_name($calculated_risk);

                $scoring_method = $risk[0]['scoring_method'];
                $CLASSIC_likelihood = $risk[0]['CLASSIC_likelihood'];
                $CLASSIC_impact = $risk[0]['CLASSIC_impact'];
                $AccessVector = $risk[0]['CVSS_AccessVector'];
                $AccessComplexity = $risk[0]['CVSS_AccessComplexity'];
                $Authentication = $risk[0]['CVSS_Authentication'];
                $ConfImpact = $risk[0]['CVSS_ConfImpact'];
                $IntegImpact = $risk[0]['CVSS_IntegImpact'];
                $AvailImpact = $risk[0]['CVSS_AvailImpact'];
                $Exploitability = $risk[0]['CVSS_Exploitability'];
                $RemediationLevel = $risk[0]['CVSS_RemediationLevel'];
                $ReportConfidence = $risk[0]['CVSS_ReportConfidence'];
                $CollateralDamagePotential = $risk[0]['CVSS_CollateralDamagePotential'];
                $TargetDistribution = $risk[0]['CVSS_TargetDistribution'];
                $ConfidentialityRequirement = $risk[0]['CVSS_ConfidentialityRequirement'];
                $IntegrityRequirement = $risk[0]['CVSS_IntegrityRequirement'];
                $AvailabilityRequirement = $risk[0]['CVSS_AvailabilityRequirement'];

                if ($submission_date == "")
                {
                        $submission_date = "N/A";
                }
                else $submission_date = date('Y-m-d g:i A T', strtotime($submission_date));

                // Get the mitigation for the risk
                $mitigation = get_mitigation_by_id($id);

                $mitigation_date = htmlentities($mitigation[0]['submission_date']);
                $planning_strategy = htmlentities($mitigation[0]['planning_strategy']);
                $mitigation_effort = htmlentities($mitigation[0]['mitigation_effort']);
                $current_solution = htmlentities($mitigation[0]['current_solution']);
                $security_requirements = htmlentities($mitigation[0]['security_requirements']);
                $security_recommendations = htmlentities($mitigation[0]['security_recommendations']);

                if ($mitigation_date == "")
                {
                        $mitigation_date = "N/A";
                }
                else $mitigation_date = date('Y-m-d g:i A T', strtotime($mitigation_date));

		// If the risk level is high and they have permission
		if (($risk_level == "High") && ($_SESSION['review_high'] == 1))
		{
			// Review is approved
			$approved = true;
		}
		// If the risk level is medium and they have permission
		else if (($risk_level == "Medium") && ($_SESSION['review_medium'] == 1))
		{
                        // Review is approved
                        $approved = true;
		}
		// If the risk level is low and they have permission
		else if (($risk_level == "Low") && ($_SESSION['review_low'] == 1))
		{
                        // Review is approved
                        $approved = true;
		}
        }

	// If they are not approved to review the risk
	if (!($approved))
	{
		// There is an alert
		$alert = true;
		$alert_message = "You do not have permission to review " . $risk_level . " level risks.  Any reviews that you attempt to submit will not be recorded.  Please contact an administrator if you feel that you have reached this message in error.";
	}

        // Check if a new risk mitigation was submitted
        if (isset($_POST['submit']))
        {
		// If they are approved to review the risk
		if ($approved)
		{
                	$status = "Mgmt Reviewed";
                	$review = (int)addslashes($_POST['review']);
			$next_step = (int)addslashes($_POST['next_step']);
                	$reviewer = $_SESSION['uid'];
                	$comments = addslashes($_POST['comments']);

                	// Submit review
                	submit_management_review($id, $status, $review, $next_step, $reviewer, $comments);

                	// Audit log
                	$risk_id = $id;
                	$message = "A management review was submitted for risk ID \"" . $risk_id . "\" by username \"" . $_SESSION['user'] . "\".";
                	write_log($risk_id, $_SESSION['uid'], $message);

			// If the reviewer rejected the risk
			if ($review == 2)
			{
                		$status = "Closed";
                		$close_reason = "The risk was rejected by the reviewer.";
                		$note = "Risk was closed automatically when the reviewer rejected the risk.";

                		// Close the risk
                		close_risk($risk_id, $_SESSION['uid'], $status, $close_reason, $note);

                		// Audit log
                		$message = "Risk ID \"" . $risk_id . "\" automatically closed when username \"" . $_SESSION['user'] . "\" rejected the risk.";
                		write_log($risk_id, $_SESSION['uid'], $message);
			}

			// Redirect to plan mitigations page
			header('Location: management_review.php?reviewed=true'); 
		}
		// They do not have permissions to review the risk
		else
		{
                	// There is an alert
                	$alert = true;
                	$alert_message = "You do not have permission to review " . $risk_level . " level risks.  The review that you attempted to submit was not recorded.  Please contact an administrator if you feel that you have reached this message in error.";
		}
        }
?>

<!doctype html>
<html>
  
  <head>
    <script src="../js/jquery.min.js"></script>
    <script src="../js/bootstrap.min.js"></script>
    <title>SimpleRisk: Enterprise Risk Management Simplified</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <link rel="stylesheet" href="../css/bootstrap.css">
    <link rel="stylesheet" href="../css/bootstrap-responsive.css"> 
  </head>
  
  <body>
    <? if ($alert) echo "<script>alert(\"" . $alert_message . "\");</script>"; ?>
    <title>SimpleRisk: Enterprise Risk Management Simplified</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type">
    <link rel="stylesheet" href="../css/bootstrap.css">
    <link rel="stylesheet" href="../css/bootstrap-responsive.css">
    <link rel="stylesheet" href="../css/divshot-util.css">
    <link rel="stylesheet" href="../css/divshot-canvas.css">
    <div class="navbar">
      <div class="navbar-inner">
        <div class="container">
          <a class="brand" href="http://www.simplerisk.org/">SimpleRisk</a>
          <div class="navbar-content">
            <ul class="nav">
              <li>
                <a href="../index.php">Home</a> 
              </li>
              <li class="active">
                <a href="index.php">Risk Management</a> 
              </li>
              <li>
                <a href="../reports/index.php">Reporting</a> 
              </li>
<?
if ($_SESSION["admin"] == "1")
{
          echo "<li>\n";
          echo "<a href=\"../admin/index.php\">Configure</a>\n";
          echo "</li>\n";
}
          echo "</ul>\n";
          echo "</div>\n";

if ($_SESSION["access"] == "granted")
{
          echo "<div class=\"btn-group pull-right\">\n";
          echo "<a class=\"btn dropdown-toggle\" data-toggle=\"dropdown\" href=\"#\">".$_SESSION['name']."<span class=\"caret\"></span></a>\n";
          echo "<ul class=\"dropdown-menu\">\n";
          echo "<li>\n";
          echo "<a href=\"../account/profile.php\">My Profile</a>\n";
          echo "</li>\n";
          echo "<li>\n";
          echo "<a href=\"../logout.php\">Logout</a>\n";
          echo "</li>\n";
          echo "</ul>\n";
          echo "</div>\n";
}
?>
        </div>
      </div>
    </div>
    <div class="container-fluid">
      <div class="row-fluid">
        <div class="span3">
          <ul class="nav  nav-pills nav-stacked">
            <li>
              <a href="index.php">I. Submit Your Risks</a> 
            </li>
            <li>
              <a href="plan_mitigations.php">II. Plan Your Mitigations</a> 
            </li>
            <li class="active">
              <a href="management_review.php">III. Perform Management Reviews</a> 
            </li>
            <li>
              <a href="prioritize_planning.php">IV. Prioritize for Project Planning</a> 
            </li>
            <li>
              <a href="review_risks.php">V. Review Risks Regularly</a>
            </li>
          </ul>
        </div>
        <div class="span9">
          <div class="row-fluid">
            <div class="well">
              <form name="submit_management_review" method="post" action="">
                <h4>Submit Management Review</h4>
                <h4>Risk ID: <? echo $id ?></h4>
                <h4>Subject: <? echo $subject ?></h4>
                <h4>Calculated Risk: <? echo $calculated_risk . " (". get_risk_level_name($calculated_risk) . ")"; ?></h4>
                Review: <? create_dropdown("review"); ?><br />
	        Next Step: <? create_dropdown("next_step"); ?><br />
                <label>Comments</label>
                <textarea name="comments" cols="50" rows="3" id="comments"></textarea>
                <div class="form-actions">
                  <button type="submit" name="submit" class="btn btn-primary">Submit</button>
                  <input class="btn" value="Reset" type="reset">
                </div>
              </form>
            </div>
          </div>
          <div class="row-fluid">
            <div class="span6">
              <div class="well">
                <h4>Details</h4>
                Submission Date: <input type="text" name="submission_date" id="submission_date" size="50" value="<? echo $submission_date ?>" disabled="disabled" /><br />
                Subject: <input type="text" name="subject" id="subject" size="50" value="<? echo htmlentities($subject) ?>" disabled="disabled" /><br />
                External Reference ID: <input type="text" name="reference_id" id="reference_id" size="20" value="<? echo htmlentities($reference_id) ?>" disabled="disabled" /><br />
                Site/Location: <input type="text" name="location" id="location" size="50" value="<? echo get_name_by_value("location", $location) ?>" disabled="disabled" /><br />
                Category: <input type="text" name="category" id="category" size="50" value="<? echo get_name_by_value("category", $category) ?>" disabled="disabled" /><br />
                Team: <input type="text" name="team" id="team" size="50" value="<? echo get_name_by_value("team", $team) ?>" disabled="disabled" /><br />
                Technology: <input type="text" name="technology" id="technology" size="50" value="<? echo get_name_by_value("technology", $technology) ?>" disabled="disabled" /><br />
                Owner: <input type="text" name="owner" id="owner" size="50" value="<? echo get_name_by_value("user", $owner) ?>" disabled="disabled" /><br />
                Owner&#39;s Manager: <input type="text" name="manager" id="manager" size="50" value="<? echo get_name_by_value("user", $manager) ?>" disabled="disabled" /><br />
<?
        // If this is CLASSIC risk scoring
        if ($scoring_method == 1)
        {
                echo "Current Likelihood: \n";
                echo "<input type=\"text\" name=\"likelihood\" id=\"likelihood\" size=\"50\" value=\"" . get_name_by_value("likelihood", $CLASSIC_likelihood) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Current Impact: \n";
                echo "<input type=\"text\" name=\"impact\" id=\"impact\" size=\"50\" value=\"" . get_name_by_value("impact", $CLASSIC_impact) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
        }
        // If this is CVSS risk scoring
        else if ($scoring_method == "2")
        {
                echo "Attack Vector: \n";
                echo "<input type=\"text\" name=\"AccessVectorVar\" id=\"AccessVectorVar\" size=\"50\" value=\"" . get_cvss_name("AccessVector", $AccessVector) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Attack Complexity: \n";
                echo "<input type=\"text\" name=\"AccessComplexityVar\" id=\"AccessComplexityVar\" size=\"50\" value=\"" . get_cvss_name("AccessComplexity", $AccessComplexity) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Authentication: \n";
                echo "<input type=\"text\" name=\"AuthenticationVar\" id=\"AuthenticationVar\" size=\"50\" value=\"" . get_cvss_name("Authentication", $Authentication) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Confidentiality Impact: \n";
                echo "<input type=\"text\" name=\"ConfImpactVar\" id=\"ConfImpactVar\" size=\"50\" value=\"" . get_cvss_name("ConfImpact", $ConfImpact) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Integrity Impact: \n";
                echo "<input type=\"text\" name=\"IntegImpactVar\" id=\"IntegImpactVar\" size=\"50\" value=\"" . get_cvss_name("IntegImpact", $IntegImpact) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Availability Impact: \n";
                echo "<input type=\"text\" name=\"AvailImpactVar\" id=\"AvailImpactVar\" size=\"50\" value=\"" . get_cvss_name("AvailImpact", $AvailImpact) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Exploitability: \n";
                echo "<input type=\"text\" name=\"ExploitabilityVar\" id=\"ExploitabilityVar\" size=\"50\" value=\"" . get_cvss_name("Exploitability", $Exploitability) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Remediation Level: \n";
                echo "<input type=\"text\" name=\"RemediationLevelVar\" id=\"RemediationLevelVar\" size=\"50\" value=\"" . get_cvss_name("RemediationLevel", $RemediationLevel) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Report Confidence: \n";
                echo "<input type=\"text\" name=\"ReportConfidenceVar\" id=\"ReportConfidenceVar\" size=\"50\" value=\"" . get_cvss_name("ReportConfidence", $ReportConfidence) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Collateral Damage Potential: \n";
                echo "<input type=\"text\" name=\"CollateralDamagePotentialVar\" id=\"CollateralDamagePotentialVar\" size=\"50\" value=\"" . get_cvss_name("CollateralDamagePotential", $CollateralDamagePotential) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Target Distribution: \n";
                echo "<input type=\"text\" name=\"TargetDistributionVar\" id=\"TargetDistributionVar\" size=\"50\" value=\"" . get_cvss_name("TargetDistribution", $TargetDistribution) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Confidentiality Requirement: \n";
                echo "<input type=\"text\" name=\"ConfidentialityRequirementVar\" id=\"ConfidentialityRequirementVar\" size=\"50\" value=\"" . get_cvss_name("ConfidentialityRequirement", $ConfidentialityRequirement) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Integrity Requirement: \n";
                echo "<input type=\"text\" name=\"IntegrityRequirementVar\" id=\"IntegrityRequirementVar\" size=\"50\" value=\"" . get_cvss_name("IntegrityRequirement", $IntegrityRequirement) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
                echo "Availability Requirement: \n";
                echo "<input type=\"text\" name=\"AvailabilityRequirementVar\" id=\"AvailabilityRequirementVar\" size=\"50\" value=\"" . get_cvss_name("AvailabilityRequirement", $AvailabilityRequirement) . "\" disabled=\"disabled\" />\n";
                echo "<br />\n";
        }
?>
                <label>Risk Assessment</label>
                <textarea name="assessment" cols="50" rows="3" id="assessment" disabled="disabled"><? echo htmlentities(stripslashes($assessment)) ?></textarea>
                <label>Additional Notes</label>
                <textarea name="notes" cols="50" rows="3" id="notes" disabled="disabled"><? echo htmlentities(stripslashes($notes)) ?></textarea>
              </div>
            </div>
            <div class="span6">
              <div class="well">
                <h4>Mitigation</h4>
                Mitigation Date: <input type="text" name="mitigation_date" id="mitigation_date" size="50" value="<? echo $mitigation_date ?>" disabled="disabled" /><br />
                Planning Strategy: <input type="text" name="planning_strategy" id="planning_strategy" size="50" value="<? echo get_name_by_value("planning_strategy", $planning_strategy) ?>" disabled="disabled" /><br />
                Mitigation Effort: <input type="text" name="mitigation_effort" id="mitigation_effort" size="50" value="<? echo get_name_by_value("mitigation_effort", $mitigation_effort) ?>" disabled="disabled" /><br />
                <label>Current Solution</label>
                <textarea name="current_solution" cols="50" rows="3" id="current_solution" disabled="disabled"><? echo htmlentities(stripslashes($current_solution)) ?></textarea>
                <label>Security Requirements</label>
                <textarea name="security_requirements" cols="50" rows="3" id="security_requirements" disabled="disabled"><? echo htmlentities(stripslashes($security_requirements)) ?></textarea>
                <label>Security Recommendations</label>
                <textarea name="security_recommendations" cols="50" rows="3" id="security_recommendations" disabled="disabled"><? echo htmlentities(stripslashes($security_recommendations)) ?></textarea>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </body>

</html>
